@@ -11,9 +11,9 @@ b,c){if(b=a.get("location")){c.body='<table style="width: 100%; padding: 0; bord
 default:return"today-item today-unknown"}},onRowContextMenu:function(a,b,c){a=a.getSelectionModel();a.isSelected(b)||a.selectRow(b);var d;if(this.folder)if(b=container.getContextByFolder(this.folder))d=b.getModel();Zarafa.core.data.UIFactory.openDefaultContextMenu(a.getSelections(),{position:c.getXY(),model:d})},onRowDblClick:function(a){a=a.getSelectionModel().getSelected();if(!Ext.isEmpty(a))if(a.isRecurringOccurence())a=a.convertToOccurenceRecord();Zarafa.core.data.UIFactory.openViewRecord(a)}});
 Zarafa.onReady(function(){container.registerWidget(new Zarafa.core.ui.widget.WidgetMetaData({name:"appointments",displayName:_("Today's Appointments"),iconPath:"plugins/folderwidgets/resources/images/appointments.png",widgetConstructor:Zarafa.widgets.folderwidgets.AppointmentsWidget}))});Ext.namespace("Zarafa.widgets.folderwidgets");
 Zarafa.widgets.folderwidgets.MailWidget=Ext.extend(Zarafa.widgets.folderwidgets.AbstractFolderWidget,{constructor:function(a){a=a||{};var b=new Zarafa.mail.MailStore;b.setDefaultSort(b.defaultSortInfo.field,b.defaultSortInfo.direction);b.setRestriction({search:Zarafa.core.data.RestrictionFactory.dataResBitmask("0x00E070003",Zarafa.core.mapi.Restrictions.BMR_EQZ,Zarafa.core.mapi.MessageFlags.MSGFLAG_READ)});Ext.applyIf(a,{height:200,autoScroll:true,layout:"fit",folderType:"inbox",store:b,items:[{xtype:"zarafa.gridpanel",
-store:b,border:true,loadMask:{msg:_("Loading mail")+"..."},sm:new Ext.grid.RowSelectionModel({singleSelect:true}),viewConfig:{deferEmptyText:false,emptyText:'<div class="emptytext">'+_("No unread mail.")+"</div>",forceFit:true,enableRowBody:true,rowSelectorDepth:15,getRowClass:this.viewConfigGetRowClass},colModel:new Ext.grid.ColumnModel({columns:[{header:_("From"),dataIndex:"sent_representing_name",menuDisabled:true,renderer:Ext.util.Format.htmlEncode},{header:_("Received"),dataIndex:"message_delivery_time",
-editable:false,menuDisabled:true,renderer:Zarafa.common.ui.grid.Renderers.datetime}]}),listeners:{rowcontextmenu:this.onRowContextMenu,rowdblclick:this.onRowDblClick,scope:this}}]});Zarafa.widgets.folderwidgets.MailWidget.superclass.constructor.call(this,a)},updateFilter:function(){this.store.filterBy(function(a){return!a.isRead()},this)},viewConfigGetRowClass:function(a,b,c){b=a.isRead()?"mail_read":"mail_unread";var d={},e="";c.body='<table cellspacing="0" cellpadding="0" border="0" style="width: 100%;">';
-c.body+="<tr>";d={};e=Zarafa.common.ui.grid.Renderers.subject(a.get("subject"),d,a);c.body+=String.format('<td style="width: 100%"><div class="grid_compact grid_compact_left {0}" style="height: 24px;">{1}</div></td>',d.css,e);d={};e=Zarafa.common.ui.grid.Renderers.attachment(a.get("hasattach"),d,a);c.body+=String.format('<td style="width: 24px"><div class="grid_compact {0}" style="height: 24px; width: 24px;">{1}</div></td>',d.css,e);d={};e=Zarafa.common.ui.grid.Renderers.importance(a.get("importance"),
+id:"unread-mail-widget",store:b,border:true,loadMask:{msg:_("Loading mail")+"..."},sm:new Ext.grid.RowSelectionModel({singleSelect:true}),viewConfig:{deferEmptyText:false,emptyText:'<div class="emptytext">'+_("No unread mail.")+"</div>",forceFit:true,enableRowBody:true,rowSelectorDepth:15,getRowClass:this.viewConfigGetRowClass},colModel:new Ext.grid.ColumnModel({columns:[{header:_("From"),dataIndex:"sent_representing_name",menuDisabled:true,renderer:Ext.util.Format.htmlEncode},{header:_("Received"),
+dataIndex:"message_delivery_time",editable:false,menuDisabled:true,renderer:Zarafa.common.ui.grid.Renderers.datetime}]}),listeners:{rowcontextmenu:this.onRowContextMenu,rowdblclick:this.onRowDblClick,scope:this}}]});Zarafa.widgets.folderwidgets.MailWidget.superclass.constructor.call(this,a)},updateFilter:function(){this.store.filterBy(function(a){return!a.isRead()},this)},viewConfigGetRowClass:function(a,b,c){b=a.isRead()?"mail_read":"mail_unread";var d={},e="";c.body='<table cellspacing="0" cellpadding="0" border="0" style="width: 100%;">';
+c.body+="<tr>";d={};e=Zarafa.common.ui.grid.Renderers.subject(a.get("subject"),d,a);c.body+=String.format('<td style="width: 100%"><div class="grid_compact grid_compact_left grid_compact_subject_cell {0}" style="height: 24px;">{1}</div></td>',d.css,e);d={};e=Zarafa.common.ui.grid.Renderers.attachment(a.get("hasattach"),d,a);c.body+=String.format('<td style="width: 24px"><div class="grid_compact {0}" style="height: 24px; width: 24px;">{1}</div></td>',d.css,e);d={};e=Zarafa.common.ui.grid.Renderers.importance(a.get("importance"),
 d,a);c.body+=String.format('<td style="width: 24px"><div class="grid_compact {0}" style="height: 24px; width: 24px;">{1}</div></td>',d.css,e);c.body+="</tr></table>";return"x-grid3-row-expanded "+b},onRowContextMenu:function(a,b,c){a=a.getSelectionModel();a.isSelected(b)||a.selectRow(b);var d;if(this.folder)if(b=container.getContextByFolder(this.folder))d=b.getModel();Zarafa.core.data.UIFactory.openDefaultContextMenu(a.getSelections(),{position:c.getXY(),model:d})},onRowDblClick:function(a){Zarafa.core.data.UIFactory.openViewRecord(a.getSelectionModel().getSelected())}});
 Zarafa.onReady(function(){container.registerWidget(new Zarafa.core.ui.widget.WidgetMetaData({name:"mail",displayName:_("Unread Mail"),iconPath:"plugins/folderwidgets/resources/images/mail.png",widgetConstructor:Zarafa.widgets.folderwidgets.MailWidget}))});Ext.namespace("Zarafa.widgets.folderwidgets");
 Zarafa.widgets.folderwidgets.TasksWidget=Ext.extend(Zarafa.widgets.folderwidgets.AbstractFolderWidget,{constructor:function(a){a=a||{};var b=new Zarafa.task.TaskStore;b.setRestriction({search:Zarafa.core.data.RestrictionFactory.dataResProperty("status",Zarafa.core.mapi.Restrictions.RELOP_NE,Zarafa.core.mapi.TaskStatus.COMPLETE)});Ext.applyIf(a,{height:200,autoScroll:true,layout:"fit",folderType:"task",store:b,items:[{xtype:"zarafa.gridpanel",store:b,border:true,loadMask:{msg:_("Loading tasks")+"..."},
