@@ -61,5 +61,5 @@ container.getNotifier().notify("info.chat",b.getDisplayName(),c)}});Zarafa.onRea
 Zarafa.plugins.xmpp.XmppPreviewPanelButton=Ext.extend(Ext.Button,{constructor:function(a){this.panel=a.panel;this.model=a.model;a=Ext.applyIf(a,{text:"Lol ik ben een knopje",listeners:{click:this.onClick,scope:this}});Zarafa.plugins.xmpp.XmppPreviewPanelButton.superclass.constructor.call(this,a)},initComponent:function(){Zarafa.plugins.xmpp.XmppPreviewPanelButton.superclass.initComponent.apply(this,arguments);this.setVisible(false);this.panel.addListener("updaterecord",this.onUpdateRecord,this);(this.xmppPlugin=
 container.getPluginByName("xmpp"))&&this.model.addListener("previewrecordchange",this.onRecordChange,this)},update:function(a){var b=undefined;if(a!=undefined){a=a.data.sent_representing_email_address;b=this.xmppPlugin.getRosterManager().getEntryByEmail(a)}if(b){this.setIconClass(Zarafa.plugins.xmpp.getIconClass(b.getPresence().getShow()));this.setText(b.getDisplayName());this.setVisible(true)}else this.setVisible(false);this.entry=b},onClick:function(){this.entry&&this.xmppPlugin.getChatManager().createChat(this.entry.getJID())},
 onRecordChange:function(a,b){this.update(b)},onUpdateRecord:function(a,b,c){this.update(c)},destroy:function(){this.panel.removeListener("updaterecord",this.onUpdateRecord,this);this.model.removeListener("previewrecordchange",this.onRecordChange,this);Zarafa.plugins.xmpp.XmppPreviewPanelButton.superclass.destroy.call(this)}});Ext.reg("zarafa.xmpp.previewpanelbutton",Zarafa.plugins.xmpp.XmppPreviewPanelButton);
-Zarafa.plugins.xmpp.XmppPreviewPanelPlugin=Ext.extend(Zarafa.core.Plugin,{initPlugin:function(){Zarafa.plugins.xmpp.XmppPreviewPanelPlugin.superclass.initPlugin.apply(this,arguments);var a=container.getPluginByName("xmpp");this.chatManager=a.getChatManager();this.rosterManager=a.getRosterManager();this.registerInsertionPoint("previewpanel.toolbar.right",function(b,c,d){return{xtype:"zarafa.xmpp.previewpanelbutton",panel:c,model:d}},this)},onMessageReceived:function(){},onPresenceChanged:function(){}});
+Zarafa.plugins.xmpp.XmppPreviewPanelPlugin=Ext.extend(Zarafa.core.Plugin,{initPlugin:function(){Zarafa.plugins.xmpp.XmppPreviewPanelPlugin.superclass.initPlugin.apply(this,arguments);var a=container.getPluginByName("xmpp");this.chatManager=a.getChatManager();this.rosterManager=a.getRosterManager();this.registerInsertionPoint("previewpanel.toolbar.right",function(b,c){return{xtype:"zarafa.xmpp.previewpanelbutton",panel:c.scope,model:c.model}},this)},onMessageReceived:function(){},onPresenceChanged:function(){}});
 Zarafa.onReady(function(){container.registerPlugin(new Zarafa.core.PluginMetaData({name:"xmpp-previewpanel-plugin",displayName:_("XMPP Preview Panel Plugin"),settingsName:"xmpp",allowUserVisible:false,pluginConstructor:Zarafa.plugins.xmpp.XmppPreviewPanelPlugin}))});
