@@ -41,7 +41,9 @@ class Pluginxmpp extends Plugin {
 							'enable' => PLUGIN_XMPP_USER_DEFAULT_ENABLE,
 							'domain' => PLUGIN_XMPP_CONNECT_DOMAIN,
 							'httpbase' => PLUGIN_XMPP_CONNECT_HTTPBASE,
-							'resource' => PLUGIN_XMPP_CONNECT_RESOURCE
+							'resource' => PLUGIN_XMPP_CONNECT_RESOURCE,
+							'port' => PLUGIN_XMPP_CONNECT_PORT,
+							'ssl' => PLUGIN_XMPP_CONNECT_SSL
 						)
 					)
 				)
